from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.swallow import image_template, latest_version

items = ImageItems(
    {
        image_template(latest_version).format("01.jpg"): "",
    }
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.anchor import image_template

docs = [
    {
        "path": "../docs/anchor/body/v1.md",
        "items": ImageItems(
            {
                image_template.format("20251204_144010.jpg"): "",
                image_template.format("20251204_144014.jpg"): "",
                image_template.format("20251204_144017.jpg"): "",
                image_template.format("20251204_144021.jpg"): "",
                image_template.format("20251204_144024.jpg"): "",
                image_template.format("20251204_144031.jpg"): "",
                image_template.format("20251205_175953.jpg"): "",
            }
        ),
    },
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.swallow_head import image_template
from bluer_sbc.README.designs.swallow_head import latest_version

items = ImageItems(
    {
        image_template(latest_version).format(f"{index+1:02}.jpg"): ""
        for index in range(6)
    }
)



from bluer_sbc.README.design import design_doc_parts

parts = {
    "16-awg-wire": "20 cm x (red + black/blue)",
    "dc-power-plug": "",
    "dc-switch": "",
    "hdmi-cable": "",
    "keyboard": "",
    "micro-hdmi-adapter": "",
    "nuts-bolts-spacers": ", ".join(
        [
            "M2.5: ({})".format(
                " + ".join(
                    [
                        "4 x bolt",
                        "4 x nut",
                        "12 x 10 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "4 x bolt",
                        "5 x nut",
                        "4 x 15 mm spacer",
                        "5 x 25 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "PCB-single-14x9_5": "",
    "plexiglass": "14 cm x 9.5 cm",
    "power-adapter": "12 V DC, 5 A",
    "rpi": "",
    "swallow-shield": "",
    "XL4015": "",
}


docs = [
    {
        "path": "../docs/cheshmak/parts.md",
        "macros": design_doc_parts(
            dict_of_parts=parts,
            parts_reference="../parts",
        ),
    }
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.cheshmak import assets2

docs = [
    {
        "path": "../docs/cheshmak/validations.md",
        "items": ImageItems(
            {
                assets2 + "bryce/09.jpg?raw=true": "",
            }
        ),
    },
]



from blueness.pypi import setup

from bluer_sbc import NAME, VERSION, DESCRIPTION, REPO_NAME

setup(
    filename=__file__,
    repo_name=REPO_NAME,
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    packages=[
        NAME,
        f"{NAME}.algo",
        f"{NAME}.hardware",
        f"{NAME}.hardware.hat",
        f"{NAME}.hardware.sparkfun_top_phat",
        f"{NAME}.help",
        f"{NAME}.imager",
        f"{NAME}.imager.camera",
        f"{NAME}.imager.lepton",
        f"{NAME}.parts",
        f"{NAME}.parts.classes",
        f"{NAME}.README",
        f"{NAME}.README.designs",
        f"{NAME}.README.designs.battery_bus",
        f"{NAME}.README.designs.battery_bus.body",
        f"{NAME}.README.designs.anchor",
        f"{NAME}.README.designs.anchor.body",
        f"{NAME}.README.designs.cheshmak",
        f"{NAME}.README.designs.cheshmak.body",
        f"{NAME}.README.designs.swallow",
        f"{NAME}.README.designs.swallow_head",
        f"{NAME}.ROS",
        f"{NAME}.session",
    ],
    include_package_data=True,
    package_data={
        NAME: [
            "config.env",
            "sample.env",
            ".abcli/**/*.sh",
        ],
    },
)



from bluer_sbc.README.design import design_doc_parts

parts = {
    "dupont-cables": "1 x 30 cm + 1 x 10 cm",
    "numpad": "",
    "nuts-bolts-spacers": " + ".join(
        [
            "M2: ({})".format(
                " + ".join(
                    [
                        "2 x bolt",
                        "4 x nut",
                        "2 x 5 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "4 x 15 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "rpi": "",
    "rpi-camera": "",
    "sd-card-32-gb": "",
    "strong-thread": "1 m",
    "swallow-shield": "",
    "ultrasonic-sensor": "4 x",
    "XL4015": "",
}


docs = [
    {
        "path": "../docs/swallow-head/parts.md",
        "macros": design_doc_parts(
            dict_of_parts=parts,
            parts_reference="../parts",
        ),
    }
]
